import type { Either, ErrorResolver } from '@lokalise/node-core';
import type { QueueConsumer, QueueOptions, Deserializer } from '@message-queue-toolkit/core';
import type { Message } from 'amqplib';
import type { AMQPConsumerDependencies, AMQPQueueConfig } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPConsumerOptions<MessagePayloadType extends object> = QueueOptions<MessagePayloadType, AMQPQueueConfig> & {
    deserializer?: Deserializer<MessagePayloadType, Message>;
};
export declare abstract class AbstractAmqpConsumer<MessagePayloadType extends object> extends AbstractAmqpService<MessagePayloadType, AMQPConsumerDependencies> implements QueueConsumer {
    private readonly transactionObservabilityManager?;
    protected readonly errorResolver: ErrorResolver;
    private readonly deserializer;
    constructor(dependencies: AMQPConsumerDependencies, options: AMQPConsumerOptions<MessagePayloadType>);
    abstract processMessage(messagePayload: MessagePayloadType): Promise<Either<'retryLater', 'success'>>;
    private deserializeMessage;
    start(): Promise<void>;
}
